Struct hypers::prelude::RustlsConfig
source · pub struct RustlsConfig {
pub key: Vec<u8>,
pub cert: Vec<u8>,
pub ocsp: Vec<u8>,
pub client_auth: ClientAuth,
}Expand description
rustls’s config.
Fields
key: Vec<u8>Private key.
cert: Vec<u8>Certificate.
ocsp: Vec<u8>OCSP response.
client_auth: ClientAuthImplementations
sourceimpl RustlsConfig
impl RustlsConfig
sourcepub fn new() -> RustlsConfig
pub fn new() -> RustlsConfig
Create a new Tls config
sourcepub fn cert(self, cert: Vec<u8>) -> RustlsConfig
pub fn cert(self, cert: Vec<u8>) -> RustlsConfig
sets the Tls certificate
sourcepub fn key(self, key: Vec<u8>) -> RustlsConfig
pub fn key(self, key: Vec<u8>) -> RustlsConfig
sets the Tls key
sourcepub fn client_auth_optional(self, trust_anchor: Vec<u8>) -> RustlsConfig
pub fn client_auth_optional(self, trust_anchor: Vec<u8>) -> RustlsConfig
Sets the trust anchor for optional Tls client authentication
sourcepub fn client_auth_required(self, trust_anchor: Vec<u8>) -> RustlsConfig
pub fn client_auth_required(self, trust_anchor: Vec<u8>) -> RustlsConfig
Sets the trust anchor for required Tls client authentication
sourcepub fn ocsp(self, ocsp: Vec<u8>) -> RustlsConfig
pub fn ocsp(self, ocsp: Vec<u8>) -> RustlsConfig
sets the DER-encoded OCSP response