#[non_exhaustive]pub struct Url<'a> { /* private fields */ }Expand description
Rust type for Swagger UI url configuration object.
Implementations
sourceimpl<'a> Url<'a>
impl<'a> Url<'a>
sourcepub fn with_primary(name: &'a str, url: &'a str, primary: bool) -> Url<'a>
pub fn with_primary(name: &'a str, url: &'a str, primary: bool) -> Url<'a>
Create new Url with primary flag.
Primary flag allows users to override the default behavior of the Swagger UI for selecting the primary
doc to display. By default when there are multiple docs in Swagger UI the first one in the list
will be the primary.
Name is shown in the select dropdown when there are multiple docs in Swagger UI.
Url is path which exposes the OpenAPI doc.
Examples
Set “My Api” as primary.
let url = Url::with_primary("My Api", "/api-docs/openapi.json", true);Trait Implementations
sourceimpl<'a> Serialize for Url<'a>
impl<'a> Serialize for Url<'a>
sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more